Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorRemigiusz Fiedler <migius@gmx.net>2008-02-04 03:44:31 +0300
committerRemigiusz Fiedler <migius@gmx.net>2008-02-04 03:44:31 +0300
commit9c12534cd9ad4e0ec432dc58525d9df7d8ccc6f5 (patch)
tree87206fc087b28ccdf83bf7ce02fb66c2128c2802 /source
parent7739d9b628d745b153286267c3a0607ed169cf9f (diff)
Python API
---------- Correct sound into font in documentation to api2_2x/doc/Font.py.
Diffstat (limited to 'source')
-rw-r--r--source/blender/python/api2_2x/doc/Font.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/python/api2_2x/doc/Font.py b/source/blender/python/api2_2x/doc/Font.py
index c0ad66d0462..44fa3d81f91 100644
--- a/source/blender/python/api2_2x/doc/Font.py
+++ b/source/blender/python/api2_2x/doc/Font.py
@@ -52,17 +52,17 @@ class Font:
def pack():
"""
- Packs the sound into the current blend file.
- @note: An error will be raised if the sound is already packed or the filename path does not exist.
+ Packs the font into the current blend file.
+ @note:
@returns: nothing
@rtype: none
"""
def unpack(mode):
"""
- Unpacks the sound to the samples filename.
+ Unpacks the font.
@param mode: One of the values in Blender.UnpackModes dict.
- @note: An error will be raised if the sound is not packed or the filename path does not exist.
+ @note: An error will be raised if the font is not packed or the filename path does not exist.
@returns: nothing
@rtype: none
@type mode: int